@@ -3,6 +3,7 @@
 
 #include <zypp-curl/ng/network/networkrequesterror.h>
 #include <zypp-curl/ng/network/TransferSettings>
+#include <zypp-curl/ng/network/curlmultiparthandler.h>
 #include <zypp-core/zyppng/base/Base>
 #include <zypp-core/zyppng/core/Url>
 #include <zypp-core/zyppng/core/ByteArray>
@@ -17,6 +18,7 @@
 
 namespace zypp {
   class Digest;
+  class CheckSum;
 
   namespace media {
     class AuthData;
@@ -71,25 +73,7 @@ namespace zyppng {
     };
     ZYPP_DECLARE_FLAGS(Options, OptionBits);
 
-    struct Range {
-      size_t start = 0;
-      size_t len = 0;
-      size_t bytesWritten = 0;
-      DigestPtr _digest; //< zypp::Digest that is updated when data is written, can be used to validate the file contents with a checksum
-
-      /**
-      * Enables automated checking of downloaded contents against a checksum.
-      * Only makes a difference if \ref _digest is initialized too
-      *
-      * \note expects checksum in byte NOT in string format
-      */
-      CheckSumBytes _checksum;
-      std::optional<size_t> _relevantDigestLen; //< If this is initialized , it defines how many bytes of the resulting checkum are compared
-      bool _valid = false;
-      std::any userData; //< Custom data the user can associate with the Range
-
-      static Range make ( size_t start, size_t len = 0, DigestPtr &&digest = nullptr, CheckSumBytes &&expectedChkSum = CheckSumBytes(), std::any &&userData = std::any(), std::optional<size_t> digestCompareLen = {} );
-    };
+    using Range = CurlMultiPartHandler::Range;
 
     struct Timings {
       std::chrono::microseconds namelookup;
@@ -106,7 +90,7 @@ namespace zyppng {
      * \param fMode The mode in which the file is opened in.
      */
     NetworkRequest(Url url, zypp::Pathname targetFile, FileMode fMode = WriteExclusive );
-    virtual ~NetworkRequest();
+    ~NetworkRequest() override;
 
     /*!
      * Sets the expected file size for the download.
@@ -115,6 +99,8 @@ namespace zyppng {
      */
     void setExpectedFileSize ( zypp::ByteCount expectedFileSize );
 
+    zypp::ByteCount expectedFileSize() const;
+
     /*!
      * Sets the priority of the NetworkRequest, this will affect where
      * the \sa NetworkRequestDispatcher puts the Request in the Queue.
@@ -143,9 +129,15 @@ namespace zyppng {
      * Adds a new range to the requested range list, the ranges can not overlap
      * \note This will not change a running download
      */
-    void addRequestRange ( size_t start, size_t len = 0, DigestPtr digest = nullptr, CheckSumBytes expectedChkSum = CheckSumBytes(), std::any userData = std::any(), std::optional<size_t> digestCompareLen = {}  );
+    void addRequestRange ( size_t start, size_t len = 0, std::optional<zypp::Digest> &&digest = {}, CheckSumBytes expectedChkSum = CheckSumBytes(), std::any userData = std::any(), std::optional<size_t> digestCompareLen = {}, std::optional<size_t> chksumpad = {}  );
 
-    void addRequestRange ( const Range &range );
+    void addRequestRange ( Range &&range );
+
+    /*!
+     * Sets the expected checksum for the full file.
+     * \note This will not change a running download
+     */
+    bool setExpectedFileChecksum( const zypp::CheckSum &expected );
 
     /*!
      * Clears all requested ranges, the next download will get the complete file
@@ -223,6 +215,8 @@ namespace zyppng {
     /**
      * Returns the number of bytes that are reported from the backend as the full download size, those can
      * be 0 even when the download is already running.
+     * \note When downloading ranges, the reported byte count could be reported just partially due to
+     *       range batching.
      */
     zypp::ByteCount reportedByteCount() const;
 
@@ -264,6 +258,17 @@ namespace zyppng {
      */
     bool addRequestHeader(const std::string &header );
 
+    /*!
+     * Return the currently used path for the cookie file
+     */
+    const zypp::Pathname &cookieFile() const;
+
+    /*!
+     * Set path to use for the cookie file if enabled via TransferSettings.
+     * \note calling this on a already running request has no impact
+     */
+    void setCookieFile( zypp::Pathname cookieFile );
+
     /**
      * Signals that the dispatcher dequeued the request and actually starts downloading data
      */
