@@ -37,7 +37,7 @@ namespace zypp
   /// use outside this class. \ref operator== tells if the checksums
   /// of two rRepoStatus are the same.
   ///////////////////////////////////////////////////////////////////
-  class RepoStatus
+  class ZYPP_API RepoStatus
   {
     friend std::ostream & operator<<( std::ostream & str, const RepoStatus & obj );
     friend RepoStatus operator&&( const RepoStatus & lhs, const RepoStatus & rhs );
@@ -109,13 +109,13 @@ namespace zypp
   ///////////////////////////////////////////////////////////////////
 
   /** \relates RepoStatus Stream output */
-  std::ostream & operator<<( std::ostream & str, const RepoStatus & obj );
+  std::ostream & operator<<( std::ostream & str, const RepoStatus & obj ) ZYPP_API;
 
   /** \relates RepoStatus Combine two RepoStatus (combined checksum and newest timestamp) */
-  RepoStatus operator&&( const RepoStatus & lhs, const RepoStatus & rhs );
+  RepoStatus operator&&( const RepoStatus & lhs, const RepoStatus & rhs ) ZYPP_API;
 
   /** \relates RepoStatus Whether 2 RepoStatus refer to the same content checksum */
-  bool operator==( const RepoStatus & lhs, const RepoStatus & rhs );
+  bool operator==( const RepoStatus & lhs, const RepoStatus & rhs ) ZYPP_API;
 
   /** \relates RepoStatus Whether 2 RepoStatus refer to different content checksums */
   inline bool operator!=( const RepoStatus & lhs, const RepoStatus & rhs )
