@@ -50,7 +50,7 @@ namespace internal {
   using namespace zypp;
   struct ProgressData
   {
-    ProgressData( CURL *curl, time_t timeout = 0, zypp::Url  url = zypp::Url(),
+    ProgressData( AutoFILE file, CURL *curl, time_t timeout = 0, zypp::Url  url = zypp::Url(),
                   zypp::ByteCount expectedFileSize_r = 0,
                   zypp::callback::SendReport<zypp::media::DownloadProgressReport> *_report = nullptr );
 
@@ -73,8 +73,21 @@ namespace internal {
     void expectedFileSize( ByteCount newval_r )
     { _expectedFileSize = newval_r; }
 
+    zypp::Url url() const
+    { return _url; }
+
+    FILE* file()
+    { return _file.value(); }
+
+    size_t writeBytes( char *ptr, ByteCount bytes );
+
+    ByteCount bytesWritten() const {
+      return _bytesWritten;
+    }
+
   private:
     CURL *      _curl;
+    AutoFILE    _file;
     zypp::Url	_url;
     time_t	_timeout;
     bool	_timeoutReached;
@@ -91,6 +104,8 @@ namespace internal {
     curl_off_t _dnlLast	 = 0.0;	///< Bytes downloaded at period start
     curl_off_t _dnlNow	 = 0.0;	///< Bytes downloaded now
 
+    ByteCount _bytesWritten = 0; ///< Bytes actually written into the file
+
     int    _dnlPercent= 0;	///< Percent completed or 0 if _dnlTotal is unknown
 
     double _drateTotal= 0.0;	///< Download rate so far
@@ -99,8 +114,9 @@ namespace internal {
 
 
 
-  ProgressData::ProgressData(CURL *curl, time_t timeout, Url url, ByteCount expectedFileSize_r, zypp::callback::SendReport< zypp::media::DownloadProgressReport> *_report)
+  ProgressData::ProgressData(AutoFILE file, CURL *curl, time_t timeout, Url url, ByteCount expectedFileSize_r, zypp::callback::SendReport< zypp::media::DownloadProgressReport> *_report)
     : _curl( curl )
+    , _file( std::move(file) )
     , _url(std::move( url ))
     , _timeout( timeout )
     , _timeoutReached( false )
@@ -131,9 +147,6 @@ namespace internal {
     if ( _timeout )
       _timeoutReached = ( (now - _timeRcv) > _timeout );
 
-    // check if the downloaded data is already bigger than what we expected
-    _fileSizeExceeded = _expectedFileSize > 0 && _expectedFileSize < static_cast<ByteCount::SizeType>(_dnlNow);
-
     // percentage:
     if ( _dnlTotal )
       _dnlPercent = int( _dnlNow * 100 / _dnlTotal );
@@ -163,6 +176,18 @@ namespace internal {
     return 0;
   }
 
+  size_t ProgressData::writeBytes(char *ptr, ByteCount bytes)
+  {
+    // check if the downloaded data is already bigger than what we expected
+    _fileSizeExceeded = _expectedFileSize > 0 && _expectedFileSize < ( _bytesWritten + bytes );
+    if ( _fileSizeExceeded )
+      return 0;
+
+    auto written = fwrite( ptr, 1, bytes, _file );
+    _bytesWritten += written;
+    return written;
+  }
+
   /// Attempt to work around certain issues by autoretry in MediaCurl::getFileCopy
   /// E.g. curl error: 92: HTTP/2 PROTOCOL_ERROR as in bsc#1205843, zypper/issues/457,...
   /// ma: These errors were caused by a space terminated user agent string (bsc#1212187)
@@ -666,13 +691,19 @@ void MediaCurl::getFileCopyFromMirror(const int mirror, const OnMediaLocation &s
         ZYPP_THROW(MediaCurlSetOptException(fileurl, _curlError));
       }
 
-      ret = curl_easy_setopt( curl, CURLOPT_WRITEDATA, file.value() );
+      // Set callback and perform.
+      internal::ProgressData progressData( file, curl, settings.timeout(), fileurl, srcFile.downloadSize(), &report );
+
+      ret = curl_easy_setopt( curl, CURLOPT_WRITEDATA,  &progressData  );
+      if ( ret != 0 ) {
+        ZYPP_THROW(MediaCurlSetOptException(fileurl, _curlError));
+      }
+
+      ret = curl_easy_setopt( curl, CURLOPT_WRITEFUNCTION, &MediaCurl::writeCallback );
       if ( ret != 0 ) {
         ZYPP_THROW(MediaCurlSetOptException(fileurl, _curlError));
       }
 
-      // Set callback and perform.
-      internal::ProgressData progressData( curl, settings.timeout(), fileurl, srcFile.downloadSize(), &report );
       report->start(fileurl, dest);
 
       if ( curl_easy_setopt( curl, CURLOPT_PROGRESSDATA, &progressData ) != 0 ) {
@@ -680,6 +711,10 @@ void MediaCurl::getFileCopyFromMirror(const int mirror, const OnMediaLocation &s
       }
 
       ret = executeCurl( rData );
+
+      // flush buffers
+      fflush ( file );
+
   #if CURLVERSION_AT_LEAST(7,19,4)
       // bnc#692260: If the client sends a request with an If-Modified-Since header
       // with a future date for the server, the server may respond 200 sending a
@@ -1107,19 +1142,22 @@ int MediaCurl::progressCallback( void *clientp, curl_off_t dltotal, curl_off_t d
   {
     // work around curl bug that gives us old data
     long httpReturnCode = 0;
-    if ( curl_easy_getinfo( pdata->curl(), CURLINFO_RESPONSE_CODE, &httpReturnCode ) != CURLE_OK || httpReturnCode == 0 )
+    if ( curl_easy_getinfo( pdata->curl(), CURLINFO_RESPONSE_CODE, &httpReturnCode ) != CURLE_OK || httpReturnCode == 0 ) {
       return aliveCallback( clientp, dltotal, dlnow, ultotal, ulnow );
-
+    }
     pdata->updateStats( dltotal, dlnow );
     return pdata->reportProgress();
   }
   return 0;
 }
 
-CURL *MediaCurl::progressCallback_getcurl( void *clientp )
+size_t MediaCurl::writeCallback( char *ptr, size_t size, size_t nmemb, void *userdata )
 {
-  internal::ProgressData *pdata = reinterpret_cast<internal::ProgressData *>(clientp);
-  return pdata ? pdata->curl() : 0;
+  internal::ProgressData *pdata = reinterpret_cast<internal::ProgressData *>( userdata );
+  if( pdata ) {
+    return pdata->writeBytes ( ptr, size * nmemb );
+  }
+  return 0;
 }
 
 ///////////////////////////////////////////////////////////////////
